==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/InquiryInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.InquiryInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Details about inquired protectable items under a given container.
 * @property inquiryDetails Inquiry Details which will have workload specific details.
 * For e.g. - For SQL and oracle this will contain different details.
 * @property status Inquiry Status for this container such as
 * InProgress | Failed | Succeeded
 */
public data class InquiryInfoArgs(
    public val inquiryDetails: Output<List<WorkloadInquiryDetailsArgs>>? = null,
    public val status: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.InquiryInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.InquiryInfoArgs =
        com.pulumi.azurenative.recoveryservices.inputs.InquiryInfoArgs.builder()
            .inquiryDetails(
                inquiryDetails?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .status(status?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InquiryInfoArgs].
 */
@PulumiTagMarker
public class InquiryInfoArgsBuilder internal constructor() {
    private var inquiryDetails: Output<List<WorkloadInquiryDetailsArgs>>? = null

    private var status: Output<String>? = null

    /**
     * @param value Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("aexmjplhkguxtyal")
    public suspend fun inquiryDetails(`value`: Output<List<WorkloadInquiryDetailsArgs>>) {
        this.inquiryDetails = value
    }

    @JvmName("nkwdqlgmtrpjilnl")
    public suspend fun inquiryDetails(vararg values: Output<WorkloadInquiryDetailsArgs>) {
        this.inquiryDetails = Output.all(values.asList())
    }

    /**
     * @param values Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("vdebgmtgykjiqpbg")
    public suspend fun inquiryDetails(values: List<Output<WorkloadInquiryDetailsArgs>>) {
        this.inquiryDetails = Output.all(values)
    }

    /**
     * @param value Inquiry Status for this container such as
     * InProgress | Failed | Succeeded
     */
    @JvmName("imqiwjapytlbymmi")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("kenrlctqegptbrpf")
    public suspend fun inquiryDetails(`value`: List<WorkloadInquiryDetailsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.inquiryDetails = mapped
    }

    /**
     * @param argument Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("xkvhnkgxdfcelrgt")
    public suspend
    fun inquiryDetails(argument: List<suspend WorkloadInquiryDetailsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WorkloadInquiryDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.inquiryDetails = mapped
    }

    /**
     * @param argument Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("vuihvjyscgfbmkju")
    public suspend fun inquiryDetails(
        vararg
        argument: suspend WorkloadInquiryDetailsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            WorkloadInquiryDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.inquiryDetails = mapped
    }

    /**
     * @param argument Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("rqjbvpkhyxqykmex")
    public suspend
    fun inquiryDetails(argument: suspend WorkloadInquiryDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(WorkloadInquiryDetailsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.inquiryDetails = mapped
    }

    /**
     * @param values Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("sforndsvldskgoyx")
    public suspend fun inquiryDetails(vararg values: WorkloadInquiryDetailsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inquiryDetails = mapped
    }

    /**
     * @param value Inquiry Status for this container such as
     * InProgress | Failed | Succeeded
     */
    @JvmName("oghjlxegwdcbepuy")
    public suspend fun status(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): InquiryInfoArgs = InquiryInfoArgs(
        inquiryDetails = inquiryDetails,
        status = status,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/InquiryInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.InquiryInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Details about inquired protectable items under a given container.
 * @property inquiryDetails Inquiry Details which will have workload specific details.
 * For e.g. - For SQL and oracle this will contain different details.
 * @property status Inquiry Status for this container such as
 * InProgress | Failed | Succeeded
 */
public data class InquiryInfoArgs(
    public val inquiryDetails: Output<List<WorkloadInquiryDetailsArgs>>? = null,
    public val status: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.InquiryInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.InquiryInfoArgs =
        com.pulumi.azurenative.recoveryservices.inputs.InquiryInfoArgs.builder()
            .inquiryDetails(
                inquiryDetails?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .status(status?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InquiryInfoArgs].
 */
@PulumiTagMarker
public class InquiryInfoArgsBuilder internal constructor() {
    private var inquiryDetails: Output<List<WorkloadInquiryDetailsArgs>>? = null

    private var status: Output<String>? = null

    /**
     * @param value Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("fkcfauwwcnxsulmr")
    public suspend fun inquiryDetails(`value`: Output<List<WorkloadInquiryDetailsArgs>>) {
        this.inquiryDetails = value
    }

    @JvmName("xofigbsndugqsaop")
    public suspend fun inquiryDetails(vararg values: Output<WorkloadInquiryDetailsArgs>) {
        this.inquiryDetails = Output.all(values.asList())
    }

    /**
     * @param values Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("pgqlbmtjxjvpuxsb")
    public suspend fun inquiryDetails(values: List<Output<WorkloadInquiryDetailsArgs>>) {
        this.inquiryDetails = Output.all(values)
    }

    /**
     * @param value Inquiry Status for this container such as
     * InProgress | Failed | Succeeded
     */
    @JvmName("pdofylxghsccptff")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("hyuslacywinlfhbn")
    public suspend fun inquiryDetails(`value`: List<WorkloadInquiryDetailsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.inquiryDetails = mapped
    }

    /**
     * @param argument Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("jxlionrlmvhwmjun")
    public suspend
    fun inquiryDetails(argument: List<suspend WorkloadInquiryDetailsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WorkloadInquiryDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.inquiryDetails = mapped
    }

    /**
     * @param argument Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("hygfyuprufdsmxpv")
    public suspend fun inquiryDetails(
        vararg
        argument: suspend WorkloadInquiryDetailsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            WorkloadInquiryDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.inquiryDetails = mapped
    }

    /**
     * @param argument Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("erwanklghxhjuquj")
    public suspend
    fun inquiryDetails(argument: suspend WorkloadInquiryDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(WorkloadInquiryDetailsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.inquiryDetails = mapped
    }

    /**
     * @param values Inquiry Details which will have workload specific details.
     * For e.g. - For SQL and oracle this will contain different details.
     */
    @JvmName("lbydkxvaltghqult")
    public suspend fun inquiryDetails(vararg values: WorkloadInquiryDetailsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inquiryDetails = mapped
    }

    /**
     * @param value Inquiry Status for this container such as
     * InProgress | Failed | Succeeded
     */
    @JvmName("ptqllvjsqwghrlnn")
    public suspend fun status(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): InquiryInfoArgs = InquiryInfoArgs(
        inquiryDetails = inquiryDetails,
        status = status,
    )
}
